@@ -31,7 +31,8 @@ xf.exposure_time = 0.13
 xf.exposure_bias_value = -50.34
 xf.aperture_value = 12.34
 xf.max_aperture_value = 99.99
-xf.focal_length = 150
+xf.focal_length = 150.3
+xf.focal_length_in_35_mm_film = 45
 xf.custom_rendered = True
 xf.iso_speed_ratings = 400
 xf.white_balance = False
